@@ -5,7 +5,7 @@ Application Name: gmapss (Google Maps Search)
 Functionality Purpose: Acquire google maps data of a place based on query
 Version: Beta
 '''
-#10/13/20
+#5/25/20
 
 # &gws_rd=cr -> implement optional redirects
 
@@ -96,19 +96,22 @@ class GoogleMaps:
                self.__dict__[attr] = None
    def __set_url(self, url_exists: re): # set the url, title & coords attributes
       if url_exists:
-         prefix = re.sub(r"\?q=", "/place/", self.__mq).replace('+', "\+")
-         path = re.search(fr'{prefix}.+?/data.+?\\"', self.__resp.text).group()
-         path = re.sub(r"\\\\u003d", '=', path)
-         coords = re.search(r"@-?\d\d?\.\d{4,8},-?\d\d?\.\d{4,8}",
-                            url_exists.group()).group()
-         self.coords = self.coordinates = tuple(coords.strip('@').split(','))
-         path = re.sub(r"/data", f"/{coords},17z/data", path)
-         self.url = path[:-11] + "!8m2!3d" + re.sub(r",", "!4d", coords.strip('@'))
-         title = re.search(r"(?<=https://www.google.com/maps/place/)\w+.*?/@",
-                                self.url).group().strip("/@")
-         self.title = unquote_plus(title)
+         try:
+            prefix = re.sub(r"\?q=", "/place/", self.__mq).replace('+', "\+")
+            path = re.search(fr'{prefix}.+?/data.+?\\"', self.__resp.text).group()
+            path = re.sub(r"\\\\u003d", '=', path)
+            coords = re.search(r"@-?\d\d?\.\d{4,8},-?\d\d?\.\d{4,8}",
+                               url_exists.group()).group()
+            self.coords = self.coordinates = tuple(coords.strip('@').split(','))
+            path = re.sub(r"/data", f"/{coords},17z/data", path)
+            self.url = path[:-11] + "!8m2!3d" + re.sub(r",", "!4d", coords.strip('@'))
+            title = re.search(r"(?<=https://www.google.com/maps/place/)\w+.*?/@",
+                                    self.url).group().strip("/@")
+            self.title = unquote_plus(title)
+         except AttributeError:
+            pass
    def __set_attrs(self, query: str, fields: list=[]):
-      resp = self.__sesh.get(self.__sq + quote_plus(query)); resp.html.render()
+      resp = self.__sesh.get(self.__sq + quote_plus(query)); resp.html.render(timeout=30)
       if self.__fields_valid and len(fields) != 0:
          attrs_switch(self, resp.html.html, fields)
       else:
@@ -130,6 +133,9 @@ class GoogleMaps:
       parsed = re.sub(r"(<td)? class=\"\w+\">", '', table)
       dow = re.sub(r"</td><td>", ' ', parsed).split("</td></tr><tr>")
       for row in dow:
+         if len(row) > 24:
+            row = re.sub(r"<div>.+?</div>", '', row)
+         row = re.sub(r"<div><span", '', row)
          day = row.split(' ')[0]
          open_times = row.split(' ')[1]
          self.open_hours["Hours"][day] = open_times
@@ -147,8 +153,7 @@ class GoogleMaps:
       days = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"]
       i = 0
       for day in ptimes:
-         parse = re.sub(r"(?<=]).+", '', day).strip("[]") + ','
-         prep = parse.replace(',', "{},")
+         prep = day.replace(',', "{},")
          times = prep.format(*self.__pop_hours()).strip(',')
          self.popular_times[days[i]] = times.split(','); i += 1
    def __set_values(self, fields: list=[]):
@@ -246,6 +251,8 @@ class GoogleMapsResults:
           Q = query.replace(' ','\+')
           expr = fr"/search\?q={Q}&amp;npsic.+?\""
           href = re.search(expr, resp.html.html)
+          if not href:
+              return None
       self.url = list_link = "https://www.google.com" +\
                  href.group().replace("&amp;", '&').strip('"')
       if self.__pn > 1:
